summaryrefslogtreecommitdiffstats
path: root/ash/shell.h
diff options
context:
space:
mode:
authorthakis@chromium.org <thakis@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-11-17 05:51:08 +0000
committerthakis@chromium.org <thakis@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-11-17 05:51:08 +0000
commit58ba19cd3dc7bb3321e313724997cc598d3cc2cb (patch)
treea7f1626fbfc25b0f5dd9cfdeb7ef9a493fce000f /ash/shell.h
parent665a41d72507cf65f2e096bd9023f22412f05019 (diff)
downloadchromium_src-58ba19cd3dc7bb3321e313724997cc598d3cc2cb.zip
chromium_src-58ba19cd3dc7bb3321e313724997cc598d3cc2cb.tar.gz
chromium_src-58ba19cd3dc7bb3321e313724997cc598d3cc2cb.tar.bz2
Revert r235502 "Add a full screen virtual keyboard to virtual keyboard root window"
Test has been failing on Win8 Aura since it landed. [ RUN ] VirtualKeyboardWindowControllerTest.VirtualKeyboardWindowTest [1816:612:1115/193527:1412105:FATAL:display_manager.cc(571)] Check failed: 1u == updated_display_info_list.size() (1 vs. 2)Multiple display test does not work on Win8 bots. Please skip (don't disable) the test using SupportsMultipleDisplays() Backtrace: base::debug::StackTrace::StackTrace [0x6C8EBBF1+33] logging::LogMessage::~LogMessage [0x6C71D2FE+94] ash::internal::DisplayManager::UpdateDisplays [0x5BA229F5+293] ash::internal::DisplayManager::OnNativeDisplaysChanged [0x5BA22173+2723] ash::internal::DisplayManager::InitFromCommandLine [0x5BA1E281+817] ash::Shell::Init [0x5B7628A2+210] ash::Shell::CreateInstance [0x5B75C8D9+361] ash::test::AshTestHelper::SetUp [0x01782E29+281] ash::test::AshTestBase::SetUp [0x017753AC+332] ash::test::VirtualKeyboardWindowControllerTest::SetUp [0x016A57D7+247] testing::internal::HandleExceptionsInMethodIfSupported<testing::Test,void> [0x0174E3BF+319] testing::Test::Run [0x01738DDB+107] testing::TestInfo::Run [0x017397ED+221] testing::TestCase::Run [0x01739F9F+239] testing::internal::UnitTestImpl::RunAllTests [0x017408ED+701] testing::internal::HandleExceptionsInMethodIfSupported<testing::internal::UnitTestImpl,bool> [0x0174EFE7+327] testing::UnitTest::Run [0x0173F150+192] base::TestSuite::Run [0x0172DD00+240] main [0x01647767+103] __tmainCRTStartup [0x018B870F+447] (f:\dd\vctools\crt_bld\self_x86\crt\src\crtexe.c:555) mainCRTStartup [0x018B853F+15] (f:\dd\vctools\crt_bld\self_x86\crt\src\crtexe.c:371) BaseThreadInitThunk [0x750D8543+14] RtlInitializeExceptionChain [0x775DAC69+133] RtlInitializeExceptionChain [0x775DAC3C+88] http://build.chromium.org/p/chromium.win/builders/Win8%20Aura/builds/12680/steps/ash_unittests/logs/stdio BUG=310331 TBR=bshe@chromium.org Review URL: https://codereview.chromium.org/74693002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@235520 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell.h')
-rw-r--r--ash/shell.h11
1 files changed, 2 insertions, 9 deletions
diff --git a/ash/shell.h b/ash/shell.h
index 410be21..6bab5b1 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -269,9 +269,6 @@ class ASH_EXPORT Shell
// Called when the user logs in.
void OnLoginStateChanged(user::LoginStatus status);
- // Called after the logged-in user's profile is ready.
- void OnLoginUserProfilePrepared();
-
// Called when the login status changes.
// TODO(oshima): Investigate if we can merge this and |OnLoginStateChanged|.
void UpdateAfterLoginStatusChange(user::LoginStatus status);
@@ -286,10 +283,6 @@ class ASH_EXPORT Shell
// Initializes |launcher_|. Does nothing if it's already initialized.
void CreateLauncher();
- // Creates virtual keyboard. Deletes the old virtual keyboard if it's already
- // exist.
- void CreateKeyboard();
-
// Show shelf view if it was created hidden (before session has started).
void ShowLauncher();
@@ -546,8 +539,8 @@ class ASH_EXPORT Shell
void Init();
- // Initializes virtual keyboard controller.
- void InitKeyboard();
+ // Initializes virtual keyboard controller and attaches it to |root|.
+ void InitKeyboard(internal::RootWindowController* root);
// Initializes the root window so that it can host browser windows.
void InitRootWindow(aura::Window* root_window);